<?php
// Build query URL here

class DispletRetsIdxQuery{
	public function get_query_url($model) {
		// Retrieve default settings from settings page
		$displet_rets_idx_option = displet_rets_idx_get_global_options();

		// Set base query URL
		if ($displet_rets_idx_option['displet_rets_idx_option_displet_url']) {
			$query_url = $displet_rets_idx_option['displet_rets_idx_option_displet_url'];
		}
		else {
			$query_url = 'http://api.oodle.com/api/v2/listings?key=579B95506556&format=json&jsoncallback=none&num_images=1&image_sizes=m&start=1';
			// Listings per page
			if (!is_numeric($displet_rets_idx_option['displet_rets_idx_option_listings_per_page'])) {
				$displet_rets_idx_option['displet_rets_idx_option_listings_per_page'] = 10;
			}
			$query_url .= '&num=' . $displet_rets_idx_option['displet_rets_idx_option_listings_per_page'];
			// Sorting
			if ($displet_rets_idx_option['displet_rets_idx_option_listings_sort'] == 'price-descending') {
				$sortby = 'price_reverse';
			}
			else{
				$sortby = 'price';
			}
			$query_url .= '&sort=' . $sortby;
		}

		// Translations - make an Oodle URL query parameter in the form of $model[url_parameter] from each existing $model[parameter] so that each $model[parameter] = url_parameter for '&url_parameter='
		if (!empty($model['minlistprice']) && !empty($model['maxlistprice'])) {
			$model['price'] = (intval($model['minlistprice']) * 1000) . '_' . (intval($model['maxlistprice']) * 1000);
		}
		else if (!empty($model['minlistprice'])) {
			$model['price'] = (intval($model['minlistprice']) * 1000) . '+';
		}
		else if (!empty($model['maxlistprice'])) {
			$model['price'] = (intval($model['maxlistprice']) * 1000) . '-';
		}
		if (!empty($model['minbedrooms'])) {
			$model['bedrooms'] = $model['minbedrooms'] . '+';
		}
		if (!empty($model['maxbedrooms'])) {
			$model['bedrooms'] = $model['maxbedrooms'] . '-';
		}
		if (!empty($model['minbathrooms'])) {
			$model['bathrooms'] = $model['minbathrooms'] . '+';
		}
		if (!empty($model['maxbathrooms'])) {
			$model['bathrooms'] = $model['maxbathrooms'] . '-';
		}
		if (!empty($model['minsquarefeet']) && !empty($model['maxsquarefeet'])) {
			$model['square_feet'] = $model['minsquarefeet'] . '_' . $model['maxsquarefeet'];
		}
		else if (!empty($model['minsquarefeet'])) {
			$model['square_feet'] = $model['minsquarefeet'] . '+';
		}
		else if (!empty($model['maxsquarefeet'])) {
			$model['square_feet'] = $model['maxsquarefeet'] . '-';
		}
		if (!empty($model['area'])) {
			/* Prefers to have nationwide region instead of default if location is queried, but need to adapt for Canada
			$model['region'] = 'usa';
			*/
			$model['location'] = $model['area'] . '&radius=0';
		}
		if (!empty($model['area_mls_defined'])) {
			/* Prefers to have nationwide region instead of default if location is queried, but need to adapt for Canada
			$model['region'] = 'usa';
			*/
			$model['location'] = $model['area_mls_defined'] . '&radius=0';
		}
		if (!empty($model['city'])) {
			/* Prefers to have nationwide region instead of default if location is queried, but need to adapt for Canada
			$model['region'] = 'usa';
			*/
			$model['location'] = $model['city'] . '&radius=0';
		}
		if (!empty($model['property_type'])) {
			if (!empty($model['category'])) {
				// Available to housing/sale & housing/rent
				if ($model['property_type'] == 'house') {
					$model['category'] .= '/home';
				}
				else if ($model['property_type'] == 'condo') {
					$model['category'] .= '/condo';
				}
				else if ($model['property_type'] == 'commercial') {
					$model['category'] .= '/commerical';
				}
				else if ($model['property_type'] == 'mobile') {
					$model['category'] .= '/mobile';
				}
				else if ($model['property_type'] == 'vacation') {
					$model['category'] .= '/vacation';
				}
				else if ($model['property_type'] == 'other') {
					$model['category'] .= '/other';
				}
				else if ($model['property_type'] == 'open_house') {
					$model['category'] .= '/open_house';
				}
				else if ($model['property_type'] == 'storage') {
					$model['category'] .= '/storage';
				}
				// Available only to housing/sale
				else if ($model['property_type'] == 'land' && $model['category'] == 'housing/sale') {
					$model['category'] .= '/land';
				}
				else if ($model['property_type'] == 'multi' && $model['category'] == 'housing/sale') {
					$model['category'] .= '/multi_family';
				}
				else if ($model['property_type'] == 'ranch' && $model['category'] == 'housing/sale') {
					$model['category'] .= '/farm';
				}
				// Available only to housing/rent
				else if ($model['property_type'] == 'apartment' && $model['category'] == 'housing/rent') {
					$model['category'] .= '/apartment';
				}
				else if ($model['property_type'] == 'garage' && $model['category'] == 'housing/rent') {
					$model['category'] .= '/garage';
				}
				else if ($model['property_type'] == 'roommates' && $model['category'] == 'housing/rent') {
					$model['category'] .= '/roommates';
				}
				else if ($model['property_type'] == 'short_term' && $model['category'] == 'housing/rent') {
					$model['category'] .= '/short_term';
				}
				// Switch category to rent if property_type="lease"
				else if ($model['property_type'] == 'lease') {
					$model['category'] = 'housing/rent';
				}
			}
		}
		if ($model['pool_on_property'] == 'yes') {
			$model['amenities'] = 'pool';
		}
		if (!empty($model['keyword'])) {
			$model['q'] = $model['keyword'];
		}
		if (!empty($model['zip'])) {
			/* Prefers to have nationwide region instead of default if location is queried, but need to adapt for Canada
			$model['region'] = 'usa';
			*/
			$model['location'] = $model['zip'] . '&radius=0';
		}
		if ($model['is_gated_community'] == 'yes') {
			if (isset($model['amenities'])) {
				$model['amenities'] .= ',amenities_gated';
			}
			else {
				$model['amenities'] = 'gated';
			}
		}


		// Add each parameter from $parameters to the query URL when $model[parameter] = url_parameter for '&url_parameter='
		$parameters = array('region', 'category', 'location', 'q');
		foreach ($parameters as $parameter) {
			if (isset($model[$parameter])) {
				$query_url .= '&' . $parameter . '=' . str_replace(' ', '%20', $model[$parameter]);
			}	
		}

		// Add each Oodle attribute from $attributes to the query URl in the form of &attributes=all_attributes
		$attributes = array('price', 'bedrooms', 'bathrooms', 'square_feet', 'amenities');
		$first = true;
		foreach ($attributes as $attribute) {
			if (isset($model[$attribute])) {
				if ($first) {
					$query_url .= '&attributes=';
				}
				else {
					$query_url .= ',';
				}
				$query_url .= $attribute . '_' . $model[$attribute];
				$first = false;
			}	
		}

		return $query_url;
	}
}

?>